# tex-anki-cli-tool

A CLI tool which parses LaTeX documents and outputs standard-format flashcards which can be uploaded to external tools e.g. Anki

# Example

```bash
texmemo extract measure-theory-notes.tex all \
--section theorem:proof --section definition --force
texmemo export all out.csv --tag --force
texmemo upload out.csv "MATH4408 Definitions"
```
